function Cplot(xMin, xInc, xIters, nInstances, dataName, ...
    canName, capName, snmfName, alsName, alsrName, svdName, alsr5Name, latName, nmfName, ...
    saveName, sparseName, addLegend, xlabelStr, ylabelStr, varargin)

plot_option = 0;
th1 = 0;   % Used for splitting the error for alpha intervals
%[MIN, th1), [th1, th2), [th2, MAX];
th2 = 5;
MIN = -inf;
MAX = inf;
for i = 1 : numel(varargin)
    if isequal(varargin{i}, 'plot_option')
        plot_option = varargin{i+1};
    end
    if isequal(varargin{i}, 'th1')
        th1 = varargin{i+1};
    end
    if isequal(varargin{i}, 'th2')
        th2 = varargin{i+1};
    end
end

switch plot_option
    case 0
        mixedErrorFunction = @(A, B, C, col, row) ...
            norm(A - MixProd(B, C, col, row), 'fro') / norm(A, 'fro');
        saveNameAppendix = '';
        performPlotting(xMin, xInc, xIters, nInstances, dataName, ...
            canName, capName, snmfName, alsName, alsrName, svdName, alsr5Name, latName, nmfName, ...
            saveName, sparseName, addLegend, xlabelStr, ylabelStr, mixedErrorFunction, saveNameAppendix);
    case 1
        % Find what elements correspond to beta >= threshold and
        % beta < threshold
        mixedErrorAbove = @(A, B, C, col, row) ...
            errorSplitAtThreshold(A, B, C, col, row, th2, MAX);
        mixedErrorInRange = @(A, B, C, col, row) ...
            errorSplitAtThreshold(A, B, C, col, row, th1, th2);
        mixedErrorBelow = @(A, B, C, col, row) ...
            errorSplitAtThreshold(A, B, C, col, row, MIN, th1);
        saveNameAppendixAbove = 'Above';
        saveNameAppendixInRange = 'InRange';
        saveNameAppendixBelow = 'Below';
        performPlotting(xMin, xInc, xIters, nInstances, dataName, ...  % above
            canName, capName, snmfName, alsName, alsrName, svdName, alsr5Name, latName, nmfName, ...
            saveName, sparseName, addLegend, xlabelStr, ylabelStr, mixedErrorAbove, saveNameAppendixAbove);
        performPlotting(xMin, xInc, xIters, nInstances, dataName, ...  % in range
            canName, capName, snmfName, alsName, alsrName, svdName, alsr5Name, latName, nmfName, ...
            saveName, sparseName, addLegend, xlabelStr, ylabelStr, mixedErrorInRange, saveNameAppendixInRange);
        performPlotting(xMin, xInc, xIters, nInstances, dataName, ...  % below
            canName, capName, snmfName, alsName, alsrName, svdName, alsr5Name, latName, nmfName, ...
            saveName, sparseName, addLegend, xlabelStr, ylabelStr, mixedErrorBelow, saveNameAppendixBelow);
    otherwise
        error('Wrong plotting option.');
end



end


function performPlotting(xMin, xInc, xIters, nInstances, dataName, ...
    canName, capName, snmfName, alsName, alsrName, svdName, alsr5Name, latName, nmfName, ...
    saveName, sparseName, addLegend, xlabelStr, ylabelStr, mixedErrorFunction, saveNameAppendix)
saveName = strcat(saveName(1:end-4), saveNameAppendix, '.pdf');
saveNameFig = strcat(saveName(1:end-3), 'fig');  % Replacing .pdf with .fig


% Params.
FontSize = 30;
mn = 10;
LW = 1.2;
MarkerSize = 10;
xLegendShift = 0.04;
yLegendShift = 0.02;
yLegendShiftSparse = 0.065;
% axisShift = params.inc_ / 6;

N_ALGORITHMS = 4;
cols = tolcolqual(N_ALGORITHMS);
mrk = {'-o', '-v', '-*',  '-x', '-^', '-x'};
colorMapTol = containers.Map;
markers_ = containers.Map;
for i = 1 : N_ALGORITHMS
    switch i
        case 1
            algName_ = 'LAT';
        case 2
            algName_ = 'NMF';
        case 3
            algName_ = 'SVD';
        case 4
            algName_ = 'CAN';
        otherwise
    end
    colorMapTol(algName_) = cols(i, :);
    markers_(algName_) = mrk{i};
end


% Find xVals range.
xVals = nan(xIters, 1);
for i = 1 : xIters
    xVals(i) = xMin + (i-1)*xInc;
end

if numel(xVals) > 10
    tickInc = 3 * xInc;
else
    tickInc = 2 * xInc;
end
ticks = min(xVals) : tickInc : max(xVals);

shiftX = xInc / 20;

load(dataName);

plot_can = 0;
plot_nmf = 0;
plot_svd = 0;
plot_lat = 0;
if exist(canName)
    plot_can = 1;
end
if exist(capName)
    plot_cap = 1;
end
if exist(snmfName)
    plot_snmf = 1;
end
if exist(alsName)
    plot_als = 1;
end
if exist(alsrName)
    plot_alsr = 1;
end
if exist(svdName)
    plot_svd = 1;
end
if exist(alsr5Name)
    plot_alsr5 = 1;
end
if exist(latName)
    plot_lat = 1;
end
if exist(nmfName)
    plot_nmf = 1;
end

if plot_can == 1
    load(canName);
    resultsCan = nan(xIters, nInstances);
end
% if plot_cap == 1
%     load(capName);
%     resultsCap = nan(xIters, nInstances);
% end
% if plot_snmf == 1
%     load(snmfName);
%     resultsSnmf = nan(xIters, nInstances);
% end
% if plot_als == 1
%     load(alsName);
%     resultsAls = nan(xIters, nInstances);
% end
% if plot_alsr == 1
%     load(alsrName);
%     resultsAlsr = nan(xIters, nInstances);
% end
if plot_svd == 1
    load(svdName);
    resultsSVD = nan(xIters, nInstances);
end
% if plot_alsr5 == 1
%     load(alsr5Name);
%     resultsAlsr5 = nan(xIters, nInstances);
% end
if plot_lat == 1
    load(latName);
    resultsLat = nan(xIters, nInstances);
end
if plot_nmf== 1
    load(nmfName);
    resultsNMF = nan(xIters, nInstances);
end





%% Frobenius error
for i = 1 : xIters
    for j = 1 : nInstances
        if plot_can == 1
            resultsCan(i, j) = frobRelative(Aorig{i}{j}, MaxProduct(Bcan{i}{j}, Ccan{i}{j}));
        end
        %         if plot_snmf == 1
        %             resultsSnmf(i, j) = frobRelative(Aorig{i}{j}, Bsnmf{i}{j}*Csnmf{i}{j});
        %         end
        %         if plot_als == 1
        %             resultsAls(i, j) = frobRelative(Aorig{i}{j}, Bals{i}{j}*Cals{i}{j});
        %         end
        %         if plot_alsr == 1
        %             resultsAlsr(i, j) = frobRelative(Aorig{i}{j}, Balsr{i}{j}*Calsr{i}{j});
        %         end
        if plot_svd == 1
            resultsSVD(i, j) = frobRelative(Aorig{i}{j}, Bsvd{i}{j}*Csvd{i}{j});
        end
        %         if plot_alsr5 == 1
        %             resultsAlsr5(i, j) = frobRelative(Aorig{i}{j}, Balsr5{i}{j}*Calsr5{i}{j});
        %         end
        if plot_lat == 1
            resultsLat(i, j) = mixedErrorFunction(Aorig{i}{j}, Blat{i}{j}, Clat{i}{j}, colLat{i}{j}, rowLat{i}{j});
        end
        if plot_nmf== 1
            resultsNMF(i, j) = frobRelative(Aorig{i}{j}, Bnmf{i}{j}*Cnmf{i}{j});
        end
    end
end

legends = {};

figure
hold on
if plot_lat == 1
    errorbar(xVals - shiftX, mean(resultsLat, 2), std(resultsLat, 0, 2), markers_('LAT'), 'color', colorMapTol('LAT'), ...
        'LineWidth', LW, 'markers', MarkerSize);
    legends = [legends, 'Latitude'];
end
if plot_can == 1
    errorbar(xVals, mean(resultsCan, 2), std(resultsCan, 0, 2), markers_('CAN'), 'color', colorMapTol('CAN'), ...
        'LineWidth', LW, 'markers', MarkerSize);
    legends = [legends, 'Cancer'];
end
% errorbar(xVals, mean(resultsCap, 2), std(resultsCap, 0, 2), '-xb', ...
%     'LineWidth', LW, 'markers', MarkerSize);
% errorbar(xVals, mean(resultsSnmf, 2), std(resultsSnmf, 0, 2), '-xb', ...
%     'LineWidth', LW, 'markers', MarkerSize);
% errorbar(xVals + shiftX, mean(resultsAls, 2), std(resultsAls, 0, 2), '-xg', ...
%     'LineWidth', LW, 'markers', MarkerSize);
% errorbar(xVals - shiftX, mean(resultsAlsr, 2), std(resultsAlsr, 0, 2), '-xm', ...
%     'LineWidth', LW, 'markers', MarkerSize);
if plot_svd == 1
    errorbar(xVals + 2*shiftX, mean(resultsSVD, 2), std(resultsSVD, 0, 2), markers_('SVD'), 'color', colorMapTol('SVD'), ...
        'LineWidth', LW, 'markers', MarkerSize);
    legends = [legends, 'SVD'];
end
% errorbar(xVals, mean(resultsAlsr5, 2), std(resultsAlsr5, 0, 2), '-x', 'Color', [.7 .5 0], ...
%     'LineWidth', LW, 'markers', MarkerSize);
if plot_nmf == 1
    errorbar(xVals + shiftX, mean(resultsNMF, 2), std(resultsNMF, 0, 2), '-xg', ...
        'LineWidth', LW, 'markers', MarkerSize);
    errorbar(xVals + shiftX, mean(resultsNMF, 2), std(resultsNMF, 0, 2), markers_('NMF'), 'color', colorMapTol('NMF'), ...
        'LineWidth', LW, 'markers', MarkerSize);
    legends = [legends, 'NMF'];
end
if addLegend == 1
    h = legend(legends, 'fontsize', FontSize+30, 'Location','southeast');
    %     h = legend('Cancer', 'Capricorn', 'SNMF', 'ALS', 'ALSR', 'SVD', 'ALSR5', 'Latitude', 'fontsize', FontSize+30);
    set(h,'FontSize', FontSize - mn);
    h.Position(1) = h.Position(1) + xLegendShift;
    h.Position(2) = h.Position(2) + yLegendShift;
    set(h,'Location','best')
    legend boxoff
end

xlabel(xlabelStr, 'interpreter', 'latex', 'fontsize', FontSize);
ylabel(ylabelStr, 'interpreter', 'latex', 'fontsize', FontSize);
set(gca,'fontsize', FontSize-8);
set(gca,'XTick', ticks);
set(gca,'XLim', [min(xVals), max(xVals)]);

axis tight
% x=input('adjust');

hold off
saveas(gcf, saveName, 'pdf');
saveas(gcf, saveNameFig, 'fig');
close all


% %% Factor sparsity.
% for i = 1 : xIters
%     for j = 1 : nInstances
%         resultsCan(i, j) = getSparsity(Bcan{i}{j}, Ccan{i}{j});
%         resultsCap(i, j) = getSparsity(Bcap{i}{j}, Ccap{i}{j});
%         resultsSnmf(i, j) = getSparsity(Bsnmf{i}{j}, Csnmf{i}{j});
%         resultsAls(i, j) = getSparsity(Bals{i}{j}, Cals{i}{j});
%         resultsAlsr(i, j) = getSparsity(Balsr{i}{j}, Calsr{i}{j});
%         resultsAlsr5(i, j) = getSparsity(Balsr5{i}{j}, Calsr5{i}{j});
%         resultsLat(i, j) = getSparsity(Blat{i}{j}, Clat{i}{j});
%     end
% end
%
% errorbar(xVals, mean(resultsCan, 2), std(resultsCan, 0, 2), '-xr', ...
%     'LineWidth', LW, 'markers', MarkerSize);
% hold on
% errorbar(xVals, mean(resultsCap, 2), std(resultsCap, 0, 2), '-xb', ...
%     'LineWidth', LW, 'markers', MarkerSize);
% errorbar(xVals, mean(resultsSnmf, 2), std(resultsSnmf, 0, 2), '-xb', ...
%     'LineWidth', LW, 'markers', MarkerSize);
% errorbar(xVals + shiftX, mean(resultsAls, 2), std(resultsAls, 0, 2), '-xg', ...
%     'LineWidth', LW, 'markers', MarkerSize);
% errorbar(xVals - shiftX, mean(resultsAlsr, 2), std(resultsAlsr, 0, 2), '-xm', ...
%     'LineWidth', LW, 'markers', MarkerSize);
% errorbar(xVals, mean(resultsAlsr5, 2), std(resultsAlsr5, 0, 2), '-x', 'Color', [.7 .5 0], ...
%     'LineWidth', LW, 'markers', MarkerSize);
% errorbar(xVals, mean(resultsLat, 2), std(resultsLat, 0, 2), '-x', 'Color', [.3 .5 0], ...
%     'LineWidth', LW, 'markers', MarkerSize);
%
% if addLegend == 1
%     h = legend('Cancer', 'Capricorn', 'SNMF', 'ALS', 'ALSR', 'ALSR5', 'Latitude', 'fontsize', FontSize+30);
%     %     h = legend('Cancer', 'Capricorn', 'ALS', 'fontsize', FontSize+30);
%     set(h,'FontSize', FontSize - mn);
%     h.Position(1) = h.Position(1) + xLegendShift;
%     h.Position(2) = h.Position(2) + yLegendShiftSparse;
%     legend boxoff
% end
%
% xlabel(xlabelStr, 'interpreter', 'latex', 'fontsize', FontSize);
% ylabel('Sparsity', 'interpreter', 'latex', 'fontsize', FontSize);
% set(gca,'fontsize', FontSize-8);
% set(gca,'XTick', ticks);
% set(gca,'XLim', [min(xVals), max(xVals)]);
%
% axis tight
% % x=input('adjust');
%
% hold off
% saveas(gcf, sparseName, 'pdf');
% saveas(gcf, sparseNameFig, 'fig');
% close all
end


function err = errorSplitAtThreshold(A, B, C, col, row, th1, th2)
beta = bsxfun(@plus, col, row);
I = ((beta >= th1) & beta <= th2);
err = norm((A - MixProd(B, C, col, row)).*I, 'fro') ...
    / norm(A.*I, 'fro');
end


function err_ = frobRelative(A, A_)
err_ = norm(A-A_, 'fro') / norm(A, 'fro');
end