function [ C ] = tolcolqual( n )
%TOLCOLQUAL Paul Tol's qualitative data color scheme
%   Colormap for Paul Tol's qualitative data scheme. Good for qualitative 
%   data and discrete lines. 
%
%   Usage:
%   TOLCOLQUAL(n) returns n-by-3 colormap from the scheme. The scheme has
%   12 different colours; for n > 12, they are recycled.
%
%   TOLCOLQUAL is the same as TOLCOLQUAL(size(colormap, 1))
%
%   Source: Paul Tol: Colour Schemes. SRON Technical Note
%   SRON/EPS/TN/09-002, 29 Dec 2012
%
%   See also:
%   TOLCOLDIV TOLCOLSEQ TOLCOLRAINBOW

% The full 12+1-colour scheme (the first colour is only used for n < 5)
F = [ 68 119 170;
      51  34 136;
     102 153 204;
     136 204 238;
      68 170 153;
      17 119  51;
     153 153  51;
     221 204 119;
     102  17   0;
     204 102 119;
     170  68 102;
     136  34  85;
     170  68 153]./256;
 
if nargin == 0
    n = size(colormap, 1);
end

if n <= 0
    error('colormap must have some colours');
end

switch n
    case 1
        C = F(1,:);
    case 2
        C = F([1 10], :);
    case 3
        C = F([1 8 10], :);
    case 4
        C = F([1 6 8 10], :);
    case 5
        C = F([2 4 6 8 10], :);
    case 6
        C = F([2 4 6 8 10 13], :);
    case 7
        C = F([2 4 5 6 8 10 13], :);
    case 8
        C = F([2 4 5 6 7 8 10 13], :);
    case 9
        C = F([2 4 5 6 7 8 10 12 13], :);
    case 10
        C = F([2 4 5 6 7 8 9 10 12 13], :);
    case 11
        C = F([2 3 4 5 6 7 8 9 10 12 13], :);
    case 12
        C = F([2 3 4 5 6 7 8 9 10 11 12 13], :);
    otherwise
        D = F(1:13, :);
        C = [repmat(D, idivide(n, uint32(12)), 1); D(1:(mod(n, 12)), :)];
end
end

