function [ C ] = tolcolrainbow( n )
%TOLCOLRAINBOW Paul Tol's rainbow colour scheme
%   Colormap for Paul Tol's rainbow scheme. 
%
%   Usage:
%   TOLCOLRAINBOW(n) returns n-by-3 colormap from the scheme. 
%
%   TOLCOLRAINBOW is the same as TOLCOLDIV(size(colormap, 1))
%
%   Source: Paul Tol: Colour Schemes. SRON Technical Note
%   SRON/EPS/TN/09-002, 29 Dec 2012
%
%   See also: 
%   TOLCOLDIV TOLCOLSEQ TOLCOLQUAL


if nargin == 0
    n = size(colormap, 1);
end

if n < 2, error('colormap must have at least 2 colours'); end

C = nan(n, 3);
x  = (0:(n-1))./(n-1); % x \in [0,1]
x2 = x.^2;
x3 = x.^3;
x4 = x.^4;
x5 = x.^5;
x6 = x.^6;
C(:,1) = (0.472 - 0.567*x + 4.05*x2)./(1 + 8.72*x - 19.17*x2 + 14.1*x3); % R
C(:,2) = 0.108932 - 1.22635*x + 27.284*x2 - 98.577*x3 + 163.3*x4 - 131.395*x5 + 40.634*x6; % G
C(:,3) = 1./(1.97 + 3.54*x - 68.5*x2 + 243*x3 - 297*x4 + 125*x5); % B

end
