function [ C ] = tolcolseq( n )
%TOLCOLSEQ Paul Tol's sequentieal data color scheme
%   Colormap for Paul Tol's sequential scheme. Good for continuous 
%   sequential data. 
%
%   Usage:
%   TOLCOLSEQ(n) returns n-by-3 colormap from the scheme. 
%
%   TOLCOLSEQ is the same as TOLCOLSEQ(size(colormap, 1))
%
%   Source: Paul Tol: Colour Schemes. SRON Technical Note
%   SRON/EPS/TN/09-002, 29 Dec 2012
%
%   See also: 
%   TOLCOLDIV TOLCOLRAINBOW TOLCOLQUAL

if nargin == 0
    n = size(colormap, 1);
end

if n < 2, error('colormap must have at least 2 colours'); end

C = nan(n, 3);
x  = (0:(n-1))./(n-1); % x \in [0,1]

C(:,1) = 1 - 0.392*(1 + erf((x - 0.869)./0.255)); % R
C(:,2) = 1.021 - 0.456*(1 + erf((x - 0.527)./0.376)); % G
C(:,3) = 1 - 0.493*(1 + erf((x - 0.272)./0.309)); % B

end
