function [Bbest, Cbest, thetaColBest, thetaRowBest, varargout] = Latitude(A, k, varargin)
%% Parameter.
NITER = 25;
verbose = 1;
profiling = 0;

for i = 1 : numel(varargin)
    if isequal(varargin{i}, 'NITER')
        NITER = varargin{i+1};
    end
    if isequal(varargin{i}, 'verbose')
        verbose = varargin{i+1};
    end
    if isequal(varargin{i}, 'profiling')
        profiling = varargin{i+1};
    end
end

if profiling == 1
    tic;
    errors = nan(NITER, 1);
    times = nan(NITER, 1);
end

%% Initialize the factors and the relaxation parameters.
[n, m] = size(A);
[B, C] = nnmf(A, k);


%% Initizlize the relaxation parameters.
A_ = B * C;
D = A_ - A;
% higher alpha means smaller A_
b_sorted = linspace(-5, 0, n);
sm = sum(D, 2);
[~, idx] = sort(sm, 'ascend');
thetaCol = b_sorted(idx)';
c_sorted = linspace(-5, 0, m);
sm = sum(D, 1);
[~, idx] = sort(sm, 'ascend');
thetaRow = c_sorted(idx);
Bbest = B;
Cbest = C;
thetaColBest = thetaCol;
thetaRowBest = thetaRow;
errorBest = MixTropErrorRelative(A, Bbest, Cbest, thetaColBest, thetaRowBest);


%% Alternatingly update the factors and the relaxation parameters.
for iter = 1 : NITER
    for j = 1 : m
        [C(:, j), thetaRow(j)] = ...
            solveMixRegresseon(A(:, j), B, C(:, j), thetaCol, thetaRow(j));
    end
    
    for i = 1 : n
        [B(i, :), thetaCol(i)] = ...
            solveMixRegresseon(A(i, :)', C', B(i, :)', thetaRow', thetaCol(i));
    end
    
    errorNew = MixTropErrorRelative(A, B, C, thetaCol, thetaRow);
    if errorNew < errorBest
        errorBest = errorNew;
        Bbest = B;
        Cbest = C;
        thetaColBest = thetaCol;
        thetaRowBest = thetaRow;
    end
    
    if profiling == 1
        errors(iter) = errorBest;
        times(iter) = toc;
    end
    
    if verbose == 1
        fprintf('MixTrop [iter %d]   error: %9.4f\n', ...
            iter, errorNew);
    end
end

if profiling == 1
    varargout{1} = errors;
    varargout{2} = times;
end

end