function c = solveRelaxedLeastSquares(a, B, c, alpha)
% Solves the problem min ||a - B*c||_2, where a and c are vectors, B is a
% matrix, and B*c is the relaxed max-times product with coefficients from
NITER = 1;
error_best = inf;
error_prev = MixTropErrorAlpha(a, B, c, alpha);
c_best = c;
for iter = 1 : NITER
    X = bsxfun(@times, B, c');
    % Obtain the coefficient matrix.
    [~, idx] = max(X, [], 2);
    T = bsxfun(@times, (1-alpha), ones(size(B)));
    for tt = 1 : size(T, 1)
        T(tt, idx(tt)) = 1;
    end
    Y = B .* T;
    c_prev = c;
    c = lsqnonneg(Y, a);
    error_ = MixTropErrorAlpha(a, B, c, alpha);
    if error_ > 1.2*error_prev
        c = c_prev + (c - c_prev)*0.1;
        c = max(0, c);
        error_ = MixTropErrorAlpha(a, B, c, alpha);
    end
    error_prev = error_;
    if error_ < error_best
        error_best = error_;
        c_best = c;
    end
end
c = c_best;

end